@@ -76,8 +76,8 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
         # gif_file = test_obj.write_test_summary()
         # extra.append(extras.image(gif_file, mime_type='image/gif', extension='gif'))
         #
-        test_obj.flush()
-        test_obj.log_obj.remove_logger()  # Remove original log handlers
+        # test_obj.flush()
+        # test_obj.log_obj.remove_logger()  # Remove original log handlers
         test_obj.wait(3)
         test_obj.teardown()
 
@@ -139,7 +139,7 @@ def test_mobile_obj(mobile_os_name, mobile_os_version, device_name, app_package,
         yield test_mobile_obj
 
         # Teardown
-        test_mobile_obj.log_obj.remove_logger()  # Remove original log handlers
+        # test_mobile_obj.log_obj.remove_logger()  # Remove original log handlers
         test_mobile_obj.wait(3)
         test_mobile_obj.teardown()
 
